@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,8 @@
 
 package com.openexchange.documentconverter;
 
+import java.util.Map;
+import org.apache.commons.lang.StringUtils;
 
 /**
  * {@link Properties}
@@ -61,18 +63,22 @@ public class Properties {
 
     // -------------------------------------------------------------------------
 
+    static final public String CACHE_PROPERTIES_FILENAME = "properties"; // String
+
+    static final public String CACHE_RESULT_FILENAME = "result"; // String
+
+    // -------------------------------------------------------------------------
+
     static final public String PROP_CACHE_PERSIST_ENTRY_NAME = "EntryName"; // String
 
     static final public String PROP_CACHE_HASH = "CacheHash"; // String
 
+    static final public String PROP_REMOTE_CACHE_HASH = "RemoteCacheHash"; // String
+
     static final public String PROP_INPUTFILE_HASH = "InputFileHash"; // String
 
     static final public String PROP_LOCALE = "Locale"; // String
 
-    static final public String PROP_CACHE_PROPERTIES_FILENAME = "properties"; // String
-
-    static final public String PROP_CACHE_RESULT_FILENAME = "result"; // String
-
     static final public String PROP_FILTER_SHORT_NAME = "FilterShortName"; // String
 
     static final public String PROP_IMANAGER = "IManager"; // IManager
@@ -124,7 +130,7 @@ public class Properties {
     static final public String PROP_CONVERTER_COOKIE = "ConverterCookie"; // String
 
     static final public String PROP_CACHE_ONLY = "CacheOnly"; // Boolean
-    
+
     static final public String PROP_AUTOSCALE = "AutoScale"; // Boolean
 
     static final public String PROP_HIDE_CHANGES = "HideChanges"; // Boolean
@@ -178,4 +184,9 @@ public class Properties {
     static public final String OX_RESCUEDOCUMENT_EXTENSION_APPENDIX = "_ox";
 
     static public final String OX_DOCUMENTCONVERTER_TEMPDIR_NAME = "oxdc.tmp";
+
+    @SuppressWarnings("unchecked")
+    static public <T> T getValue(Map<String, ?> map, String key) {
+        return (T) (((null != map) && (!StringUtils.isEmpty(key))) ? map.get(key) : null);
+    }
 }
